from .attributes import *
from .authentication import *
from .categories import *
from .currency  import *
from .itens import *
from .local import *
from .metrics import *
from .orders import *
from .posts import *
from .questions import *
from .shipping import *
from .user_info import * 


import requests as rq

global_url = 'https://api.mercadolibre.com'

def classifiedLocation(access_token):
    r'''
        Obtém informação de países.
    '''
    url = f'{global_url}/classified_locations/countries'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def countryInfo(access_token, country_id):
    r'''
        Obtém informação de países by country_id.  
    '''
    url = f'{global_url}/classified_locations/countries/{country_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def stateInfo(access_token, state_id):
    r'''
        Obtém estado da informação.
    '''
    url = f'{global_url}/classified_locations/states/{state_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def cityInfo(access_token, city_id):
    r'''
        Obtém estado da informação da cidade.   
    '''
    url = f'{global_url}/classified_locations/cities/{city_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def zipCodeInfo(access_token, country_id, zip_code):
    r'''
        Recupera dados da localização por código postal.  
    '''
    url = f'{global_url}/countries/{country_id}/zip_codes/{zip_code}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def zipCodeSearchBetween(access_token, country_id, zip_code_from, zip_code_to):
        r'''
            Obtém todos os códigos postais para um country_id entre dois valores dados.   
        '''
        url = f'{global_url}/country/{country_id}/zip_codes/search_between?zip_code_from={zip_code_from}&zip_code_to={zip_code_to}'
        header = {
            'Content-type': 'Application/JSON',
            'Authorization': f'Bearer {access_token}'
        }
        data = rq.get(url, headers=header)
        dataJson = data.json()
        data.close()
        return dataJson





import requests as rq

global_url = 'https://api.mercadolibre.com'


def intervalDateUserVisit(access_token, user_id, date_from, date_to):
    r'''
        Obtem as visitas que um usuário teve em um intervalo de tempo
    '''
    url = f'{global_url}/users/{user_id}/item_visits?date_from={date_from}&date_to={date_to}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def timeWindowVisits(access_token, user_id, last, unit, ending):
    r'''
        Devolve as visitas de um usuário em cada item publicado durante um período de tempo. O detalhe da informação é agrupado por intervalos de tempo
    '''
    url = f'{global_url}/users/{user_id}/items_visits/timewindow?last={last}&unit={unit}&ending={ending}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def intervalContactQuestion(access_token, user_id, date_from, date_to):
    r'''
        Devolve o total de perguntas de um usuário específico em todos os items publicados num intervalo de datas.
    '''
    url = f'{global_url}/users/{user_id}/contacts/questions?date_from={date_from}&date_to={date_to}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def timeWindowContactQuestions(access_token, user_id, last, unit):
    r'''
        O recurso permite obter as perguntas realizadas num determinado tempo nos items publicados por um seller. 
    '''
    url = f'{global_url}/users/{user_id}/contacts/questions/time_window?last={last}&unit={unit}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def intervalPhoneViews(access_token, user_id, date_from, date_to):
    r'''
        Pode obter a quantidade de vezes que fizeram clique em "Ver telefone" dentro de um item durante um período de tempo.
    '''
    url = f'{global_url}/users/{user_id}/contacts/phone_views?date_from={date_from}&date_to={date_to}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authentication': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def timeWindowPhoneViews(access_token, user_id, last, unit):
    r'''
        Devolve a quantidade de vezes que foi clicado na opção “ver telefone” para cada item de um usuário num intervalo de datas.
    '''
    url = f'{global_url}/users/{user_id}/contacts/phone_view/time_window?last={last}&unit={unit}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def timeWindowItemView(access_token, item_id, last, unit, ending):
    r'''
        Devolve as visitas de um item num intervalo de tempo, filtrando por unidade e parâmetro de finalização.  
    '''
    url = f'{global_url}/items/{item_id}/visits/time_window?last={last}&unit={unit}&ending={ending}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson



import requests as rq

global_url = 'https://api.mercadolibre.com'



def sites(access_token):
    r'''
        Devolve informação sobre os sites onde o Mercado Livre está disponível.
    '''
    url = f'{global_url}/sites'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def siteDomains(access_token, site_domain_url):
    r'''
        Devolve informação sobre o domínio.
    '''
    url = f'{global_url}/site_domains/{site_domain_url}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def siteListingTypes(access_token, site_id):
    r'''
        Devolve informação sobre o listing types.
    '''
    url = f'{global_url}/sites/{site_id}/listing_types'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def listingExposures(access_token, site_id):
    r'''
        Devolve diferentes níveis de exposição associados com todos os listing_types no Mercado Livre.
    '''
    url = f'{global_url}/sites/{site_id}/listing_exposures'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def listingPrices(access_token, site_id, price):
    r'''
        Devolve a listagem de preços para vender e comprar no Mercado Livre.
    '''
    url = f'{global_url}/sites/{site_id}/listing_prices?price={price}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }

    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def listingCategories(access_token, site_id):
    r'''
    	Devolve as categorias disponíveis no site.
    '''
    url = f'{global_url}/sites/{site_id}/categories'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def domainDiscovery(access_token, site_id, q):
    r''' 
        Preditor de categorias. Devolve a categoria e domínio correspondentes para enquadrar um anúncio baseado no título, domínio e atributos
    '''
    url = f'{global_url}/sites/{site_id}/domain_discovery/search?q={q}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def listingTypeConfig(access_token, site_id, listing_type_id):
    r'''
        Obtém a configuração especifica de listing_type.  
    '''
    url = f'{global_url}/sites/{site_id}/listing_types/{listing_type_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


import requests as rq

global_url = 'https://api.mercadolibre.com'

def itemSearchCategory(access_token, site_id, category_id):
    r'''
        Obter itens listados numa categoria.
    '''
    url = f'{global_url}/sites/{site_id}/search?category={category_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def itemKeywordSearch(access_token, site_id, keywords):
    r'''
        Obter itens de uma consulta de busca.  
    '''
    url = f'{global_url}/sites/{site_id}/search?q={keywords}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def itemNicknameSearch(access_token, site_id, nickname):
    r'''
        Obter itens das listagens por nickname.
    '''
    url = f'{global_url}/sites/{site_id}/search?nickname={nickname}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def itemSellerIdSearch(access_token, site_id, seller_id):
    r'''
        Permite listar itens por vendedor.
    '''
    url = f'{global_url}/sites/{site_id}/search?seller_id={seller_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def itemSellerIdCategorySearch(access_token, site_id, seller_id, category_id):
    r'''
        Obter itens das listagens por vendedor numa categoria específica.  
    '''
    url = f'{global_url}/sites/{site_id}/search?seller_id={seller_id}&category={category_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.post(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def itemUserIdSearch(access_token, user_id):
    r'''
        Permite listar todos os itens da conta de um vendedor.    
    '''
    url = f'{global_url}/users/{user_id}/items/search'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def itemMultiget(access_token, itens):
    r'''
        Multiget com múltiplos números de itens.  
    '''
    url = f'{global_url}/items/?ids='
    for item in itens:
        url += f'{item[0]},'
    url = url[:-1]
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def itemUserMultiget(access_token, users):
    r'''
        Multiget com múltiplos números de usário.  
    '''
    url = f'{global_url}/items/?users='
    for user in users:
        url += f'{user[0]},'
    url = url[:-1]
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def itemSearchScan(access_token, user_id, scroll_id=None):
    r'''
        Permite obter mais de 1000 itens
         correspondentes a um usuário.
    '''
    if scroll_id is not None:
        url = f'{global_url}/users/{user_id}/items/search?search_type=scan&scroll_id={scroll_id}'
        header = {
            'Content-type': 'Application/JSON',
            'Authorization': f'Bearer {access_token}' 
        }
        data = rq.get(url, headers=header)
        dataJson = data.json()
        data.close()
        return dataJson

    url = f'{global_url}/users/{user_id}/items/search?search_type=scan'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}' 
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson



import requests as rq

global_url = 'https://api.mercadolibre.com'


def questionItem(access_token, item_id):
    r'''
        Busca uma pergunta feita nos items do usuário
    '''
    url = f'{global_url}/questions/search?item={item_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def doQuestion(access_token, item_id, question_text):
    r'''
        Fazer perguntas sobre os items de outros usuários.
    '''
    url = f'{global_url}/questions'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    body = {
        'text': f'{question_text}',
        'item_id': f'{item_id}'
    }
    data = rq.post(url, headers=header, data=body)
    dataJson = data.json()
    data.close()
    return dataJson


def doAnswer(access_token, question_id, answer_text):
    r'''
    	Responder às perguntas realizadas em seus items.
    '''
    url = f'{global_url}/answers'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    body = {
        'question_id': f'{question_id}',
        'text': f'{answer_text}'
    }
    data = rq.post(url, headers=header, data=body)
    dataJson = data.json()
    data.close()
    return dataJson

def getQuestion(access_token, question_id):
    r'''
        Obter informação de uma pergunta especifica de um ID.
    '''
    url = f'{global_url}/questions/{question_id}'
    header = {
        'Content-Type': 'application/json',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def questionsBlacklist(access_token, seller_id, buyer_id):
    r'''
    	Gerenciar perguntas da blacklist.
    '''
    url = f'{global_url}/users/{seller_id}/questions_blacklist/{buyer_id}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def blockUser(access_token, seller_id, user_id):
    r'''
        Inserir usuário na blacklist
    '''
    url = f'{global_url}/users/{seller_id}/questions_blacklist'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    body = {
        'user_id': user_id
    }
    data = rq.post(url, headers=header, data=body)
    dataJson = data.json()
    data.close()
    return dataJson


def deleteBlockedUser(access_token, seller_id, user_id):
    r'''
        Remover um usuário bloqueado
    '''
    url = f'{global_url}/users/{seller_id}/questions_blacklist/{user_id}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.delete(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def receivedQuestion(access_token):
    r'''
        Perguntas recebidas por usuário.
    '''
    url = f'{global_url}/my/received_questions/search'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


import requests as rq

global_url = 'https://api.mercadolibre.com'


def categoriesAttributes(access_token, category_id):
    r'''
        Consultar atributos relacionados a categoria
    '''
    url = f'{global_url}/categories/{category_id}/attributes'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def technicalSpecsInput(access_token, category_id):
    r'''
        Obter os atributos obrigatórios de cada categoria
    '''
    url = f'{global_url}/categories/{category_id}/technical_specs/input'
    header = {
        'Content-Type': 'Application/JSON', 
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def technicalSpecsOutput(access_token, category_id):
    r'''
        Mostrar os seus produtos e como vão ser visualizados
    '''
    url = f'{global_url}/categories/{category_id}/technical_specs/output'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def conditionalAttributes(access_token, catergory_id):
    r'''
        Consultar se os atributos que tem a tag 'conditional_required' são necessários para sua publicação
    '''
    url = f'{global_url}/categories/{catergory_id}/attributes/conditional'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def incompleteTechnicalSpecs(access_token, user_id):
    r'''
        Produtos que foram penalizados com a tag 'incomplete_technical_specs'
    '''
    url = f'{global_url}/users/{user_id}/items/search?tags=incomplete_technical_specs'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson

def notApplicableAttribute(access_token, item_id):
    r'''
        Especificar atributos que não se aplicam a determinado item
    '''
    url = f'{global_url}/items/{item_id}?attributes=attributes&include_internal_attributes=true'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson



import requests as rq

global_url = 'https://api.mercadolibre.com'


def shipmentInfo(access_token, shipment_id):
    r'''
        Devolve todos os dados do envio.
    '''
    url = f'{global_url}/shipments/{shipment_id}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def itemShippingOption(access_token, item_id):
    r'''
        Devolve todos os métodos disponíveis para fazer o envio de um produto. Válido somente para envios custom.  
    '''
    url = f'{global_url}/item/{item_id}/shipping_options'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def siteShipmentMethods(access_token, site_id):
    r'''
        Devolve os métodos de entrega disponíveis num país.
    '''
    url = f'{global_url}/sites/{site_id}/shipping_methods'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def catergoryShipment(access_token, cust_id, category_id):
    r'''
        Devolve os métodos de envio disponíveis para determinada categoria
    '''
    url = f'{global_url}/users/{cust_id}/shipping_modes?category_id={category_id}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def userShippingPreferences(access_token, cust_id):
    r'''
        Devolve todos os modos de envio e serviços disponíveis para o usuário.     
    '''
    url = f'{global_url}/users/{cust_id}/shipping_preferences'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def orderShipments(access_token, order_id):
    r'''
        Devolve as informações de envio dentro da order. 
    '''
    url = f'{global_url}/orders/{order_id}/shipments'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def shipmentLabels(access_token, shipment_id):
    r'''
        Permite imprimir a etiqueta para enviar o pedido
    '''
    url = f'{global_url}/shipment_labels?shipment_id={shipment_id}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def printShipmentLabelZPL(access_token, shipment_id):
    r'''
        Permite imprimir a etiqueta em formato Zebra para enviar o pedido.
    '''
    url = f'{global_url}/shipment_labels?shipment_id={shipment_id}&response_type=zpl2'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def printShipmentPDF(access_token, shipment_id):
    r'''
        Permite imprimir a etiqueta em formato PDF para enviar o pedido.
    '''
    url = f'{global_url}/shipment_labels?shipment_id={shipment_id}&savePDF=Y'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


import requests as rq

global_url = 'https://api.mercadolibre.com/'


def currencies(access_token):
    r'''
       	Obtém estado da informação sobre todas as moedas disponíveis no Mercado Livre.     
    '''
    url = f'{global_url}/currencies'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def currencyInfo(access_token, currency_id):
    r'''
        Obtém informação sobre as moedas disponíveis no Mercado Livre por currency_id.
    '''
    url = f'{global_url}/currencies/{currency_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def currencyConversion(access_token, currency_from, currency_to):
    r'''
        Recupera a conversão das moedas que Mercado Livre utiliza nos cálculos.
    '''
    url = f'{global_url}/currency_conversions/search?from={currency_from}&to={currency_to}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson






import requests as rq

global_url = 'https://api.mercadolibre.com/'


def userMe(access_token):
    r'''
        Informação da conta do usuário.
    '''
    url = f'{global_url}users/me'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    user_data = rq.get(url, headers=header)
    dataJson = user_data.json()
    user_data.close()
    return dataJson


def user(access_token, user_id):
    r'''
        Obtém a informação do usuário que fez login na conta.
    '''
    url = f'{global_url}users/{user_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def userAddress(access_token, user_id):
    r'''
        Obtém endereços associados à conta do usuário.
    '''
    url = f'{global_url}users/{user_id}/addresses'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer f{access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def userPaymentMethods(access_token, user_id):
    r'''
        Obtém os métodos de pagamento aceitos pelo vendedor para cobrar.
    '''
    url = f'{global_url}users/{user_id}/accepted_payment_methods'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def Application(access_token, application_id):
    r'''
        Obtém dados sobre o aplicativo.
    '''
    url = f'{global_url}/applications/{application_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def userBrands(access_token, user_id):
    r'''
        Este processo recupera marcas associadas a um user_id. O atributo oficial_store identifica uma loja.
    '''
    url = f'{global_url}users/{user_id}/brands'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def classifiedPromotionPacks(access_token, user_id, listing_type=False, category_id=False):
    r'''
        Este processo recupera marcas associadas a um user_id. O atributo oficial_store identifica uma loja.
    '''
    url = f'{global_url}users/{user_id}/classifieds_promotion_packs'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization' : f'Bearer {access_token}'
    }

    if listing_type and category_id:
        url += f'/{listing_type}&CATEGORYID={category_id}'

    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson

def availableListingTypes(access_token, user_id, category_id):
    r'''
        Listing types disponivéis por usuários e categorias.
    '''
    url = f'{global_url}users/{user_id}/available_listing_types?category_id={category_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }

    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def listingTypesByID(access_token, user_id, listing_type_id, category_id):
    r'''
        Obter o listing types disponível por um tipo de listagem segundo uma categoria outorgada.
    '''
    url = f'{global_url}users/{user_id}/available_listing_type/{listing_type_id}?category_id={category_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def ApplicationPermissions(access_token, user_id, application_id):
    r'''
        Permissão do aplicativo.
    '''
    url = f'{global_url}users/{user_id}/applications/{application_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def myFeedApp(access_token, application_id):
    r'''
        Histórico de notificações
    '''
    url = f'{global_url}myfeeds?app_id={application_id}'
    header = {
        'Content-type': 'ApplicationJSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


import requests as rq



global_url = 'https://api.mercadolibre.com'

def category(access_token, category_id):
    r'''
        Devolve informação sobre a categoria.
    '''
    url = f'{global_url}/categories/{category_id}'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def categoriesAttributes(access_token, category_id):
    r'''
        Mostra os atributos e regulas com a finalidade de descrever os elementos que se guardam em cada categoria.
    '''
    url = f'{global_url}/categories/{category_id}/attributes'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def classifiedPromotionPacks(access_token, category_id):
    r'''
        Obtém packs de promoções classificadas por categorias.
    '''
    url = f'{global_url}/categories/{category_id}/classifieds_promotion_packs'
    header = {
        'Content-type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


import requests as rq

global_url = 'https://api.mercadolibre.com'


def sellerOrders(access_token, seller_id):
    r'''
        Buscar os pedidos de um vendedor
    '''
    url = f'{global_url}/orders/search?seller={seller_id}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def orderInfo(access_token, seller_id, order_id):
    r'''
        Buscar um pedido de um vendedor
    '''
    url = f'{global_url}/orders/search?seller={seller_id}&q={order_id}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def buyerOrders(access_token, buyer_id):
    r'''
        Buscar os pedidos de um comprador
    '''
    url = f'{global_url}/orders/search?buyer={buyer_id}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Beare {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def paymentInfo(access_token, payment_id):
    r'''
        Obter dados do pagamento segundo o perfil do pagador
    '''
    url = f'https://api.mercadopago.com/v1/payments/{payment_id}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def paymentMethods(access_token, site_id):
    r'''
        Retorna os métodos de pagamentos previstos pelo Mercado Pago
    '''
    url = f'{global_url}/sites/{site_id}/payment_method'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}' 
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def paymentMethodDetail(access_token, site_id, payment_method_id):
    r'''
        Retorna os dados de um método de pagament específico
    '''
    url = f'{global_url}/sites/{site_id}/payment_methods/{payment_method_id}'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def orderFeedback(access_token, order_id):
    r'''
        Obter feedbacks de um comprador ou vendedor de um pedido
    '''
    url = f'{global_url}/orders/{order_id}/feedback'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def orderBlacklist(access_token, seller_id):
    r'''
        Obter os usuários bloqueados por oferta nos items de um vendedor
    '''
    url = f'{global_url}/users/{seller_id}/order_blacklist'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson


def orderProducts(access_token, order_id):
    r'''
        Obter os dados do produto vendido no pedido
    '''
    url = f'{global_url}/orders/{order_id}/product'
    header = {
        'Content-Type': 'Application/JSON',
        'Authorization': f'Bearer {access_token}'
    }
    data = rq.get(url, headers=header)
    dataJson = data.json()
    data.close()
    return dataJson





from setuptools import setup, find_packages

VERSION = '0.0.7' 
DESCRIPTION = 'Pacote para conexão com a API do Mercado Livre'
LONG_DESCRIPTION = 'Pacote em Python trazendo conexões fáceis com os endpoints da API do Mercado Livre'

# Setting up
setup(
    name="meli-package", 
    version=VERSION,
    author="Gabriel Celestino",
    author_email="<gabrielceles1410@gmail.com>",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['requests'],

    keywords=['python', 'mercadolivre', 'meli'],
    classifiers= [
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Education",
        "Programming Language :: Python :: 3",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)


import requests as rq
import environs
import webbrowser as web
import sys

def authentication(code=False, refresh_token=False):
    env = environs.Env()
    environs.Env.read_env()
    if refresh_token:
        refresh_url = "https://api.mercadolibre.com/oauth/token"
        header = {
            'accept': 'application/json',
            'content-type': 'application/x-www-form-urlencoded'
        }
        data = {
            'grant_type': 'refresh_token',
            'client_id': env('CLIENT_ID'),
            'client_secret': env('CLIENT_SECRET'),
            'refresh_token': refresh_token
        }
        access = rq.post(refresh_url, headers=header, data=data)
        accessJson = access.json()
        access.close()
        return accessJson

    if code:
        code_url = "https://api.mercadolibre.com/oauth/token"
        header = {
            'accept': 'application/json',
            'content-type': 'application/x-www-form-urlencoded'
        }
        data = {
            'grant_type': 'authorization_code',
            'client_id': env('CLIENT_ID'),
            'client_secret': env('CLIENT_SECRET'),
            'code': f'{code}',
            'redirect_uri': env('REDIRECT_URI')
        }
        access = rq.post(code_url, headers=header, data=data)
        accessJson = access.json()
        access.close()
        return accessJson
    else:
        return 'Give at least one argument'
        